<?php
/**
 * Theme functions and definitions
 *
 * @package security_camera
 */ 

if ( ! function_exists( 'security_camera_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function security_camera_enqueue_styles() {
		wp_enqueue_style( 'cyber-security-services-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'security-camera-style', get_stylesheet_directory_uri() . '/style.css', array( 'cyber-security-services-style-parent' ), '1.0.0' );
		// Theme Customize CSS.
		require get_parent_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'security-camera-style',$cyber_security_services_custom_style );
	}
endif;
add_action( 'wp_enqueue_scripts', 'security_camera_enqueue_styles', 99 );

function security_camera_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'security-camera-featured-image', 2000, 1200, true );
	add_image_size( 'security-camera-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'security-camera' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, and column width.
	*/
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}
add_action( 'after_setup_theme', 'security_camera_setup' );

function security_camera_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'security-camera' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'security-camera' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'security-camera' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'security-camera' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'security-camera' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'security-camera' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Product Category Dropdown', 'security-camera' ),
		'id'            => 'product-cat',
		'description'   => __( 'Add widgets here to appear in your header.', 'security-camera' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'security_camera_widgets_init' );

function security_camera_customize_register() {
  	global $wp_customize;
	$wp_customize->remove_section( 'cyber_security_services_pro' );
	$wp_customize->remove_section( 'cyber_security_services_product_box_section' );
}
add_action( 'customize_register', 'security_camera_customize_register', 11 );

function security_camera_remove_my_action() {
    remove_action( 'admin_menu','cyber_security_services_gettingstarted' );
    remove_action( 'after_setup_theme','cyber_security_services_notice' );
}
add_action( 'init', 'security_camera_remove_my_action');

function security_camera_customize( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

	$wp_customize->add_section('security_camera_pro', array(
		'title'    => __('UPGRADE SECURITY PREMIUM', 'security-camera'),
		'priority' => 1,
	));

	$wp_customize->add_setting('security_camera_pro', array(
		'default'           => null,
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control(new Security_Camera_Pro_Control($wp_customize, 'security_camera_pro', array(
		'label'    => __('SECURITY CAMERA PREMIUM', 'security-camera'),
		'section'  => 'security_camera_pro',
		'settings' => 'security_camera_pro',
		'priority' => 1,
	)));

	// Services Section
	$wp_customize->add_section( 'security_camera_middle_section' , array(
    	'title'      => __( 'Services Settings', 'security-camera' ),
		'priority'   => 6,
	) );

	$wp_customize->add_setting('security_camera_middle_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('security_camera_middle_heading',array(
		'label' => esc_html__('Heading','security-camera'),
		'section' => 'security_camera_middle_section',
		'setting' => 'security_camera_middle_heading',
		'type'    => 'text'
	));

	$wp_customize->add_setting('security_camera_middle_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('security_camera_middle_title',array(
		'label' => esc_html__('Title','security-camera'),
		'section' => 'security_camera_middle_section',
		'setting' => 'security_camera_middle_title',
		'type'    => 'text'
	));

	$security_camera_args = array('numberposts' => -1);
	$security_camera_post_list = get_posts($security_camera_args);
	$s = 0;
	$security_camera_pst_sls[]= __('Select','security-camera');
	foreach ($security_camera_post_list as $key => $security_camera_p_post) {
		$security_camera_pst_sls[$security_camera_p_post->ID]=$security_camera_p_post->post_title;
	}
	for ( $s = 1; $s <= 6; $s++ ) {
		$wp_customize->add_setting('security_camera_mid_section_icon'.$s,array(
			'default' => '',
			'sanitize_callback' => 'sanitize_text_field'
		));
		$wp_customize->add_control('security_camera_mid_section_icon'.$s,array(
			'label' => esc_html__('Icon','security-camera'),
			'description' => esc_html__('Add the fontawesome class to add icon ex: fas fa-envelope','security-camera'),
			'section' => 'security_camera_middle_section',
			'setting' => 'security_camera_mid_section_icon',
			'type'    => 'text'
		));

		$wp_customize->add_setting('security_camera_middle_sec_settigs'.$s,array(
			'sanitize_callback' => 'cyber_security_services_sanitize_choices',
		));
		$wp_customize->add_control('security_camera_middle_sec_settigs'.$s,array(
			'type'    => 'select',
			'choices' => $security_camera_pst_sls,
			'label' => __('Select post','security-camera'),
			'section' => 'security_camera_middle_section',
		));
	}
	wp_reset_postdata();
}
add_action( 'customize_register', 'security_camera_customize' );

function security_camera_enqueue_comments_reply() {
  if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
    // Load comment-reply.js (into footer)
    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
  }
}
add_action('wp_enqueue_scripts', 'security_camera_enqueue_comments_reply');

if ( ! defined( 'SECURITY_CAMERA_PRO_LINK' ) ) {
	define('SECURITY_CAMERA_PRO_LINK',__('https://www.ovationthemes.com/wordpress/cctv-wordpress-theme/','security-camera'));
}

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Security_Camera_Pro_Control')):
    class Security_Camera_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( SECURITY_CAMERA_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE SECURITY PREMIUM','security-camera');?> </a>
            </div>
            <div class="col-md">
                <img class="security_camera_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('SECURITY PREMIUM - Features', 'security-camera'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'security-camera');?> </li>
                    <li class="upsell-security_camera"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'security-camera');?> </li>
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( SECURITY_CAMERA_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE SECURITY PREMIUM','security-camera');?> </a>
            </div>
        </label>
    <?php } }
endif;